//+------------------------------------------------------------------+
//|                                                                  |
//|          Copyright 2005-2014, MetaQuotes Software Corp.          |
//|                       http://www.mql4.com                        |
//+------------------------------------------------------------------+

#property copyright   "2005-2014, MetaQuotes Software Corp."
#property link        "http://www.mql4.com"

#define MagicNum  77

     //Trailing Stop {{{
extern double     BreakEven       = 35;    // Profit Lock in pips
extern double     ModifiedStop       = 25;    // Profit Lock in pips  
     //Trailing Stop }}}
     
extern int     TP       = 75000;    // Profit Lock in pips
extern int     SL       = 105;    // Profit Lock in pips  
input double TradePercentage   =0.05;
input double DecreaseFactor    =1;
input int TimeFrame            = PERIOD_D1; //PERIOD_M1 PERIOD_M5 PERIOD_M15 PERIOD_M30 PERIOD_H1 PERIOD_H4 PERIOD_D1

double LMB;
double LMS;

//+------------------------------------------------------------------+
int init()
{
   if(Digits == 3 || Digits == 5)
   {
      BreakEven = BreakEven * 10;
   }

   return(0);
}

void start()
  {
   if(Bars<100 || IsTradeAllowed()==false)
      return;


//--- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0)
     CheckForOpen();
   else                                  
     {
       TrailStops();
       CheckForOpen();
     }
   return;
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+  
void CheckForOpen()
  {
   int    res;
   double Poin = Point;
   if ((Point == 0.00001) || (Point == 0.001)) Poin *= 10;

//--- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
      
//--- buy conditions
   if (NormalizeDouble(Open[0]+25*Point,Digits)>=Ask)
     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,NormalizeDouble(Ask-SL*Poin,Digits),NormalizeDouble(Ask+TP*Poin,Digits),"",MagicNum,0,clrRoyalBlue);
      return;
     }
//--- sell conditions
   if (NormalizeDouble(Open[0]-25*Point,Digits)<=Bid)
     {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,NormalizeDouble(Bid+SL*Poin,Digits),NormalizeDouble(Bid-TP*Poin,Digits),"",MagicNum,0,clrOrangeRed);
      return;
     }
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+

//Trailing Stop {{{
void TrailStops()
{
   double Pointt = Point;
   if ((Point == 0.00001) || (Point == 0.001)) Pointt *= 10;
   int Mod;
   double sl=OrderStopLoss();
   for(int cnt=OrdersTotal()-1;cnt>=0;cnt--)
   {
      OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);
      
         if(BreakEven>0) 
           {
            if(Bid-OrderOpenPrice()>Pointt*BreakEven)
              {
               if(OrderStopLoss()<Bid-Pointt*BreakEven)
            {
               if(OrderType()==OP_BUY){
                  Mod = OrderModify(OrderTicket(),OrderOpenPrice(),NormalizeDouble(OrderOpenPrice()-ModifiedStop*Pointt,Digits),OrderTakeProfit(),0,Blue);
                               if(!Mod)
                               Print("Error in OrderModify. Error code=",GetLastError());
                               else
                               Print("Order modified successfully.");
               }
               
               if(OrderType()==OP_SELL){
                  Mod = OrderModify(OrderTicket(),OrderOpenPrice(),NormalizeDouble(OrderOpenPrice()+ModifiedStop*Pointt,Digits),OrderTakeProfit(),0,Red);
                               if(!Mod)
                               Print("Error in OrderModify. Error code=",GetLastError());
                               else
                               Print("Order modified successfully.");
               }
           }
        }
        
            if(Bid-OrderOpenPrice()>Pointt*2*BreakEven)
              {
               if(OrderStopLoss()<Bid-Pointt*2*BreakEven)
            {
               if(OrderType()==OP_BUY){
                  Mod = OrderModify(OrderTicket(),OrderOpenPrice(),NormalizeDouble(OrderOpenPrice()-2*ModifiedStop*Pointt,Digits),OrderTakeProfit(),0,Blue);
                               if(!Mod)
                               Print("Error in OrderModify. Error code=",GetLastError());
                               else
                               Print("Order modified successfully.");
               }
               
               if(OrderType()==OP_SELL){
                  Mod = OrderModify(OrderTicket(),OrderOpenPrice(),NormalizeDouble(OrderOpenPrice()+2*ModifiedStop*Pointt,Digits),OrderTakeProfit(),0,Red);
                               if(!Mod)
                               Print("Error in OrderModify. Error code=",GetLastError());
                               else
                               Print("Order modified successfully.");
               }
           }
        }
        
     }
   }
}//Trailing Stop }}}

//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//---
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MagicNum)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//--- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=0.0;
   int    orders=HistoryTotal();     // history orders total
//--- select lot size
   lot = NormalizeDouble(AccountFreeMargin()*TradePercentage/(DecreaseFactor*1000.0),1);
//--- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false)
           {
            Print("Error in history!");
            break;
           }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL)
            continue;
         //---
         if(OrderProfit()>0) lot=NormalizeDouble(AccountFreeMargin()*TradePercentage/(DecreaseFactor*1000.0),1);
         if(OrderProfit()<0) lot=NormalizeDouble(AccountFreeMargin()*TradePercentage/(DecreaseFactor*1000.0),1);
        }      
     }
//--- return lot size
   if(lot<0.01) lot=0.01;
   return(lot);
  }